defmodule Restcrud.Router do
  require Logger
  use Plug.Router

  if Application.get_env(:restcrud, :logging, false) do
    # Using Plug.Logger for logging request information
    plug(Plug.Logger)
  end

  # responsible for matching routes
  plug(:match)
  # Using Poison for JSON decoding
  # Note, order of plugs is important, by placing this _after_ the 'match' plug,
  # we will only parse the request AFTER there is a route match.
  plug(Plug.Parsers, parsers: [:json], pass: ["*/*"], json_decoder: Jason)
  # responsible for dispatching responses
  plug(:dispatch)

  # A simple route to test that the server is up
  # Note, all routes must return a connection as per the Plug spec.
  get "/ping" do
    conn
    |> put_resp_content_type("text/plain")
    |> send_resp(200, "pong!")
  end

  post "/events" do
    # Logger.info("#{conn.body_params}")

    {status, body} = process_events(conn.body_params)

    send_resp(conn, status, body)
  end

  defp process_events(event) do
    Logger.info("New event")
    changeset = Events.Events.changeset(%Events.Events{}, event)
    case Events.Repo.insert(changeset) do
      {:ok, %Events.Events{id: id}} -> {200, Jason.encode!(id)}
      {:error, %{"errors" => errors}} -> {500, Jason.encode!(errors)}
    end
  end

  # defp process_events(_) do
  #   # If we can't process anything, let them know :)
  #   {500, Poison.encode!(%{response: "Please Send Some Events!"})}
  # end

  # A catchall route, 'match' will match no matter the request method,
  # so a response is always returned, even if there is no route to match.
  match _ do
    send_resp(conn, 404, "oops... Nothing here :(")
  end
end
