defmodule Restcrud.RouterTest do
  require Logger
  use ExUnit.Case, async: true
  use Plug.Test

  import Restcrud.Router

  @opts init([])

  setup do
    :ok = Ecto.Adapters.SQL.Sandbox.checkout(Events.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(Events.Repo, {:shared, self()})
  end

  test "return plain text ping" do
    conn = conn(:get, "/ping")

    conn = call(conn, @opts)

    assert conn.state == :sent
    assert conn.status == 200
    assert get_resp_header(conn, "content-type") == ["text/plain; charset=utf-8"]
    assert conn.resp_body == "pong!"
  end

  test "save event" do
    source_event = %{title: "foo", payload: "bar"}
    json = Jason.encode!(source_event)

    conn =
      :post
      |> conn("/events", json)
      |> put_req_header("content-type", "application/json; charset=utf-8")
      |> call(@opts)

    assert conn.state == :sent
    assert conn.resp_body != nil
    id = conn.resp_body
    assert Events.Repo.get(Events.Events, id) != struct(%Events.Events{}, source_event)
  end
end
